@@ -1,6 +1,7 @@
 # system configuration generated and used by the sysconfig module
 build_time_vars = {'ABIFLAGS': '',
  'AC_APPLE_UNIVERSAL_BUILD': 0,
+ 'AIX_BUILDDATE': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
@@ -10,15 +11,15 @@ build_time_vars = {'ABIFLAGS': '',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/pkg/bin',
- 'BINLIBDEST': '/usr/pkg/lib/python3.8',
- 'BLDLIBRARY': '-L. -lpython3.8',
+ 'BINLIBDEST': '/usr/pkg/lib/python3.9',
+ 'BLDLIBRARY': '-L. -lpython3.9',
  'BLDSHARED': 'gcc -pthread -shared -L. -L/usr/lib -Wl,-R/usr/lib '
               '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
               '-Wl,-R/usr/X11R7/lib -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
               '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'sparc--netbsdelf',
+ 'BUILD_GNU_TYPE': 'mips64--netbsd',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
@@ -34,7 +35,8 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_CFLAGS_NODIST': '-std=gnu99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
-                            '-Werror=implicit-function-declaration',
+                            '-Werror=implicit-function-declaration '
+                            '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-I/usr/include -I/usr/pkg/include',
  'CONFIGURE_LDFLAGS': '-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
                       '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
@@ -43,31 +45,31 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIG_ARGS': "'--enable-shared' '--with-openssl=/usr' '--with-system-expat' "
                 "'--with-system-ffi' '--without-ensurepip' "
                 "'--without-pymalloc' '--prefix=/usr/pkg' "
-                "'--build=sparc--netbsdelf' '--host=sparc--netbsdelf' "
+                "'--build=mips64--netbsd' '--host=mips64--netbsd' "
                 "'--mandir=/usr/pkg/man' '--enable-option-checking=yes' "
-                "'build_alias=sparc--netbsdelf' 'host_alias=sparc--netbsdelf' "
+                "'build_alias=mips64--netbsd' 'host_alias=mips64--netbsd' "
                 "'CC=gcc' 'CFLAGS=-O2 -I/usr/include -I/usr/pkg/include' "
                 "'LDFLAGS=-L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib "
                 "-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib' "
                 "'LIBS=' 'CPPFLAGS=-I/usr/include -I/usr/pkg/include' "
-                "'PKG_CONFIG=/tmp/pkgbuild/lang/python38/work.sparc/.tools/bin/pkg-config' "
+                "'PKG_CONFIG=/tmp/pkgbuild/lang/python39/work.mips64eb/.tools/bin/pkg-config' "
                 "'PKG_CONFIG_PATH=' "
-                "'PKG_CONFIG_LIBDIR=/tmp/pkgbuild/lang/python38/work.sparc/.buildlink/lib/pkgconfig:/tmp/pkgbuild/lang/python38/work.sparc/.buildlink/share/pkgconfig'",
+                "'PKG_CONFIG_LIBDIR=/tmp/pkgbuild/lang/python39/work.mips64eb/.buildlink/lib/pkgconfig:/tmp/pkgbuild/lang/python39/work.mips64eb/.buildlink/share/pkgconfig'",
  'CONFINCLUDEDIR': '/usr/pkg/include',
- 'CONFINCLUDEPY': '/usr/pkg/include/python3.8',
+ 'CONFINCLUDEPY': '/usr/pkg/include/python3.9',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/tmp/pkgbuild/lang/python38/work.sparc/Python-3.8.20/coverage.info',
- 'COVERAGE_REPORT': '/tmp/pkgbuild/lang/python38/work.sparc/Python-3.8.20/lcov-report',
+ 'COVERAGE_INFO': '/tmp/pkgbuild/lang/python39/work.mips64eb/Python-3.9.19/coverage.info',
+ 'COVERAGE_REPORT': '/tmp/pkgbuild/lang/python39/work.mips64eb/Python-3.9.19/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-I. -I./Include -I/usr/include -I/usr/pkg/include -I/usr/include '
              '-I/usr/pkg/include',
  'CXX': 'c++ -pthread',
- 'DESTDIRS': '/usr/pkg /usr/pkg/lib /usr/pkg/lib/python3.8 '
-             '/usr/pkg/lib/python3.8/lib-dynload',
- 'DESTLIB': '/usr/pkg/lib/python3.8',
+ 'DESTDIRS': '/usr/pkg /usr/pkg/lib /usr/pkg/lib/python3.9 '
+             '/usr/pkg/lib/python3.9/lib-dynload',
+ 'DESTLIB': '/usr/pkg/lib/python3.9',
  'DESTPATH': '',
- 'DESTSHARED': '/usr/pkg/lib/python3.8/lib-dynload',
+ 'DESTSHARED': '/usr/pkg/lib/python3.9/lib-dynload',
  'DFLAGS': '',
  'DIRMODE': 755,
  'DIST': 'README.rst ChangeLog configure configure.ac acconfig.h pyconfig.h.in '
@@ -89,6 +91,8 @@ build_time_vars = {'ABIFLAGS': '',
  'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
+ 'EXPORTSFROM': '',
+ 'EXPORTSYMS': '',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
  'EXT_SUFFIX': '.so',
@@ -96,7 +100,6 @@ build_time_vars = {'ABIFLAGS': '',
  'FLOAT_WORDS_BIGENDIAN': 1,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
- 'GETTIMEOFDAY_NO_TZ': 0,
  'GITBRANCH': '',
  'GITTAG': '',
  'GITVERSION': '',
@@ -219,7 +222,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GCC_ASM_FOR_MC68881': 0,
  'HAVE_GCC_ASM_FOR_X64': 0,
  'HAVE_GCC_ASM_FOR_X87': 0,
- 'HAVE_GCC_UINT128_T': 0,
+ 'HAVE_GCC_UINT128_T': 1,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
  'HAVE_GETENTROPY': 1,
@@ -252,7 +255,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GETSID': 1,
  'HAVE_GETSPENT': 0,
  'HAVE_GETSPNAM': 0,
- 'HAVE_GETTIMEOFDAY': 1,
  'HAVE_GETWD': 1,
  'HAVE_GLIBC_MEMMOVE_BUG': 0,
  'HAVE_GRP_H': 1,
@@ -284,18 +286,23 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LIBRESOLV': 0,
  'HAVE_LIBSENDFILE': 0,
  'HAVE_LIBUTIL_H': 0,
+ 'HAVE_LIBUUID': 1,
  'HAVE_LINK': 1,
  'HAVE_LINKAT': 1,
+ 'HAVE_LINUX_AUXVEC_H': 0,
  'HAVE_LINUX_CAN_BCM_H': 0,
  'HAVE_LINUX_CAN_H': 0,
+ 'HAVE_LINUX_CAN_J1939_H': 0,
  'HAVE_LINUX_CAN_RAW_FD_FRAMES': 0,
  'HAVE_LINUX_CAN_RAW_H': 0,
+ 'HAVE_LINUX_CAN_RAW_JOIN_FILTERS': 0,
  'HAVE_LINUX_MEMFD_H': 0,
  'HAVE_LINUX_NETLINK_H': 0,
  'HAVE_LINUX_QRTR_H': 0,
  'HAVE_LINUX_RANDOM_H': 0,
  'HAVE_LINUX_TIPC_H': 0,
  'HAVE_LINUX_VM_SOCKETS_H': 0,
+ 'HAVE_LINUX_WAIT_H': 0,
  'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
  'HAVE_LOG2': 1,
@@ -322,6 +329,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_NETPACKET_PACKET_H': 0,
  'HAVE_NET_IF_H': 1,
  'HAVE_NICE': 1,
+ 'HAVE_NON_UNICODE_WCHAR_T_REPRESENTATION': 0,
  'HAVE_OPENAT': 1,
  'HAVE_OPENPTY': 1,
  'HAVE_PATHCONF': 1,
@@ -348,7 +356,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_PTHREAD_KILL': 1,
  'HAVE_PTHREAD_SIGMASK': 1,
  'HAVE_PTY_H': 0,
- 'HAVE_PUTENV': 1,
  'HAVE_PWRITE': 1,
  'HAVE_PWRITEV': 1,
  'HAVE_PWRITEV2': 0,
@@ -373,6 +380,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SCHED_SETAFFINITY': 0,
  'HAVE_SCHED_SETPARAM': 1,
  'HAVE_SCHED_SETSCHEDULER': 1,
+ 'HAVE_SEM_CLOCKWAIT': 0,
  'HAVE_SEM_GETVALUE': 1,
  'HAVE_SEM_OPEN': 1,
  'HAVE_SEM_TIMEDWAIT': 1,
@@ -445,6 +453,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_SYSCONF': 1,
  'HAVE_SYSEXITS_H': 1,
  'HAVE_SYS_AUDIOIO_H': 1,
+ 'HAVE_SYS_AUXV_H': 0,
  'HAVE_SYS_BSDTTY_H': 0,
  'HAVE_SYS_DEVPOLL_H': 0,
  'HAVE_SYS_DIR_H': 0,
@@ -500,7 +509,6 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
  'HAVE_UNLINKAT': 1,
- 'HAVE_UNSETENV': 1,
  'HAVE_USABLE_WCHAR_T': 0,
  'HAVE_UTIL_H': 1,
  'HAVE_UTIMENSAT': 1,
@@ -525,17 +533,17 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_X509_VERIFY_PARAM_SET1_HOST': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'sparc--netbsdelf',
+ 'HOST_GNU_TYPE': 'mips64--netbsd',
  'INCLDIRSTOMAKE': '/usr/pkg/include /usr/pkg/include '
-                   '/usr/pkg/include/python3.8 /usr/pkg/include/python3.8',
+                   '/usr/pkg/include/python3.9 /usr/pkg/include/python3.9',
  'INCLUDEDIR': '/usr/pkg/include',
- 'INCLUDEPY': '/usr/pkg/include/python3.8',
+ 'INCLUDEPY': '/usr/pkg/include/python3.9',
  'INSTALL': '/usr/bin/install -c -o pbulk -g users',
  'INSTALL_DATA': '/usr/bin/install -c -o pbulk -g users -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c -s -o pbulk -g users -m 755',
  'INSTALL_SCRIPT': '/usr/bin/install -c -o pbulk -g users -m 755',
  'INSTALL_SHARED': '/usr/bin/install -c -o pbulk -g users -m 755',
- 'INSTSONAME': 'libpython3.8.so.1.0',
+ 'INSTSONAME': 'libpython3.9.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'c++ -pthread -shared',
@@ -544,24 +552,24 @@ build_time_vars = {'ABIFLAGS': '',
             '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
             '-Wl,-R/usr/X11R7/lib',
  'LDFLAGS_NODIST': '',
- 'LDLIBRARY': 'libpython3.8.so',
+ 'LDLIBRARY': 'libpython3.9.so',
  'LDLIBRARYDIR': '',
  'LDSHARED': 'gcc -pthread -shared -L. -L/usr/lib -Wl,-R/usr/lib '
              '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -L/usr/X11R7/lib '
              '-Wl,-R/usr/X11R7/lib -L/usr/lib -Wl,-R/usr/lib -L/usr/pkg/lib '
              '-Wl,-R/usr/pkg/lib -L/usr/X11R7/lib -Wl,-R/usr/X11R7/lib',
- 'LDVERSION': '3.8',
+ 'LDVERSION': '3.9',
  'LIBC': '',
- 'LIBDEST': '/usr/pkg/lib/python3.8',
+ 'LIBDEST': '/usr/pkg/lib/python3.9',
  'LIBDIR': '/usr/pkg/lib',
  'LIBFFI_INCLUDEDIR': '/usr/pkg/include',
  'LIBM': '-lm',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBPC': '/usr/pkg/lib/pkgconfig',
- 'LIBPL': '/usr/pkg/lib/python3.8/config-3.8',
+ 'LIBPL': '/usr/pkg/lib/python3.9/config-3.9',
  'LIBPYTHON': '',
- 'LIBRARY': 'libpython3.8.a',
+ 'LIBRARY': 'libpython3.9.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-lcrypt -lintl -lpthread  -lutil -lm',
@@ -577,7 +585,7 @@ build_time_vars = {'ABIFLAGS': '',
  'LOCALMODLIBS': '',
  'MACHDEP': 'netbsd10',
  'MACHDEP_OBJS': '',
- 'MACHDESTLIB': '/usr/pkg/lib/python3.8',
+ 'MACHDESTLIB': '/usr/pkg/lib/python3.9',
  'MACOSX_DEPLOYMENT_TARGET': '',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
@@ -588,7 +596,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
                    '_operator  _collections  _abc  itertools  atexit  _signal  '
                    '_stat  time  _thread  _locale  _io  faulthandler  '
-                   '_tracemalloc  _symtable  xxsubtype',
+                   '_tracemalloc  _peg_parser  _symtable  xxsubtype',
  'MODDISABLED_NAMES': '',
  'MODLIBS': '',
  'MODOBJS': 'Modules/posixmodule.o  Modules/errnomodule.o  '
@@ -601,7 +609,7 @@ build_time_vars = {'ABIFLAGS': '',
             'Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o '
             'Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o '
             'Modules/textio.o Modules/stringio.o  Modules/faulthandler.o  '
-            'Modules/_tracemalloc.o Modules/hashtable.o  '
+            'Modules/_tracemalloc.o  Modules/_peg_parser.o  '
             'Modules/symtablemodule.o  Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': '',
@@ -621,9 +629,13 @@ build_time_vars = {'ABIFLAGS': '',
  'PACKAGE_URL': 0,
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
- 'PARSER_OBJS': '\\ Parser/myreadline.o Parser/parsetok.o Parser/tokenizer.o',
+ 'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/parsetok.o '
+                'Parser/tokenizer.o',
+ 'PEGEN_HEADERS': '\\',
+ 'PEGEN_OBJS': '\\',
  'PGO_PROF_GEN_FLAG': '-fprofile-generate',
  'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
+ 'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
  'PROFILE_TASK': '-m test --pgo',
@@ -639,33 +651,34 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHONFRAMEWORKPREFIX': '',
  'PYTHONPATH': '',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python3',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
+ 'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
                              '-I/usr/include -I/usr/pkg/include -O2 '
                              '-I/usr/include -I/usr/pkg/include -O2 '
                              '-I/usr/include -I/usr/pkg/include -std=gnu99 '
                              '-Wextra -Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
-                             '-Werror=implicit-function-declaration  '
-                             '-I./Include/internal -I. -I./Include '
-                             '-I/usr/include -I/usr/pkg/include -I/usr/include '
-                             '-I/usr/pkg/include -fPIC -DPy_BUILD_CORE_BUILTIN',
+                             '-Werror=implicit-function-declaration '
+                             '-fvisibility=hidden  -I./Include/internal -I. '
+                             '-I./Include -I/usr/include -I/usr/pkg/include '
+                             '-I/usr/include -I/usr/pkg/include -fPIC '
+                             '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -I/usr/include '
               '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include -O2 '
               '-I/usr/include -I/usr/pkg/include',
  'PY_CFLAGS_NODIST': '-std=gnu99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-Werror=implicit-function-declaration  '
-                     '-I./Include/internal',
+                     '-Werror=implicit-function-declaration '
+                     '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
                    '-I/usr/include -I/usr/pkg/include -O2 -I/usr/include '
                    '-I/usr/pkg/include -O2 -I/usr/include -I/usr/pkg/include '
                    '-std=gnu99 -Wextra -Wno-unused-result '
                    '-Wno-unused-parameter -Wno-missing-field-initializers '
-                   '-Werror=implicit-function-declaration  '
+                   '-Werror=implicit-function-declaration -fvisibility=hidden  '
                    '-I./Include/internal -I. -I./Include -I/usr/include '
                    '-I/usr/pkg/include -I/usr/include -I/usr/pkg/include -fPIC '
                    '-DPy_BUILD_CORE',
@@ -689,10 +702,10 @@ build_time_vars = {'ABIFLAGS': '',
                         '-I/usr/pkg/include -std=gnu99 -Wextra '
                         '-Wno-unused-result -Wno-unused-parameter '
                         '-Wno-missing-field-initializers '
-                        '-Werror=implicit-function-declaration  '
-                        '-I./Include/internal -I. -I./Include -I/usr/include '
-                        '-I/usr/pkg/include -I/usr/include -I/usr/pkg/include '
-                        '-fPIC',
+                        '-Werror=implicit-function-declaration '
+                        '-fvisibility=hidden  -I./Include/internal -I. '
+                        '-I./Include -I/usr/include -I/usr/pkg/include '
+                        '-I/usr/include -I/usr/pkg/include -fPIC',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -701,10 +714,9 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python38/work.sparc/Python-3.8.20',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python39/work.mips64eb/Python-3.9.19',
  'SCRIPTDIR': '/usr/pkg/lib',
  'SETPGRP_HAVE_ARG': 1,
- 'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
  'SHLIBS': '-lcrypt -lintl -lpthread  -lutil -lm',
  'SHLIB_SUFFIX': '.so',
@@ -716,7 +728,7 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_FPOS_T': 264,
  'SIZEOF_INT': 4,
  'SIZEOF_LONG': 4,
- 'SIZEOF_LONG_DOUBLE': 8,
+ 'SIZEOF_LONG_DOUBLE': 16,
  'SIZEOF_LONG_LONG': 8,
  'SIZEOF_OFF_T': 8,
  'SIZEOF_PID_T': 4,
@@ -729,8 +741,8 @@ build_time_vars = {'ABIFLAGS': '',
  'SIZEOF_VOID_P': 4,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
- 'SOABI': 'cpython-38',
- 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
+ 'SOABI': 'cpython-39',
+ 'SRCDIRS': 'Parser Parser/pegen Objects Python Modules Modules/_io Programs',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
@@ -743,20 +755,21 @@ build_time_vars = {'ABIFLAGS': '',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python38/work.sparc/Python-3.8.20 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python39/work.mips64eb/Python-3.9.19 '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python38/work.sparc/Python-3.8.20 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/tmp/pkgbuild/lang/python39/work.mips64eb/Python-3.9.19 '
                './python ./Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
  'TM_IN_SYS_TIME': 0,
+ 'TZPATH': '/usr/share/zoneinfo:/usr/lib/zoneinfo:/usr/share/lib/zoneinfo:/etc/zoneinfo',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
  'UPDATE_FILE': 'python3 ./Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 0,
- 'VERSION': '3.8',
+ 'VERSION': '3.9',
  'WINDOW_HAS_FLAGS': 0,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
@@ -768,8 +781,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/tmp/pkgbuild/lang/python38/work.sparc/Python-3.8.20',
- 'abs_srcdir': '/tmp/pkgbuild/lang/python38/work.sparc/Python-3.8.20',
+ 'abs_builddir': '/tmp/pkgbuild/lang/python39/work.mips64eb/Python-3.9.19',
+ 'abs_srcdir': '/tmp/pkgbuild/lang/python39/work.mips64eb/Python-3.9.19',
  'datarootdir': '/usr/pkg/share',
  'exec_prefix': '/usr/pkg',
  'prefix': '/usr/pkg',
